==> keyclic_sdk_api-2.2.27.tar.gz: lib/model/person_patch_preferences_notification.dart <==
part of keyclic_sdk_api.api;

class PersonPatchPreferencesNotification {
  PersonPatchPreferencesNotification({
    this.mail,
    this.push,
  });

  factory PersonPatchPreferencesNotification.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return PersonPatchPreferencesNotification(
      mail: json['mail'],
      push: json['push'],
    );
  }

  String mail;

  String push;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is PersonPatchPreferencesNotification &&
        runtimeType == other.runtimeType &&
        mail == other.mail &&
        push == other.push;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mail?.hashCode ?? 0;
    hashCode ^= push?.hashCode ?? 0;

    return hashCode;
  }

  static List<PersonPatchPreferencesNotification> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <PersonPatchPreferencesNotification>[]
        : json
            .map((dynamic value) =>
                PersonPatchPreferencesNotification.fromJson(value))
            .toList();
  }

  static Map<String, PersonPatchPreferencesNotification> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, PersonPatchPreferencesNotification>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = PersonPatchPreferencesNotification.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mail != null) 'mail': mail,
      if (push != null) 'push': push,
    };
  }

  @override
  String toString() {
    return 'PersonPatchPreferencesNotification[mail=$mail, push=$push, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/person_patch_preferences_notification.dart <==
part of keyclic_sdk_api.api;

class PersonPatchPreferencesNotification {
  PersonPatchPreferencesNotification({
    this.mail,
    this.push,
  });

  factory PersonPatchPreferencesNotification.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return PersonPatchPreferencesNotification(
      mail: json['mail'],
      push: json['push'],
    );
  }

  bool mail;

  bool push;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is PersonPatchPreferencesNotification &&
        runtimeType == other.runtimeType &&
        mail == other.mail &&
        push == other.push;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mail?.hashCode ?? 0;
    hashCode ^= push?.hashCode ?? 0;

    return hashCode;
  }

  static List<PersonPatchPreferencesNotification> listFromJson(
      List<dynamic> json) {
    return json
            ?.map((dynamic value) =>
                PersonPatchPreferencesNotification.fromJson(value))
            ?.toList() ??
        <PersonPatchPreferencesNotification>[];
  }

  static Map<String, PersonPatchPreferencesNotification> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(
              key, PersonPatchPreferencesNotification.fromJson(value));
        }) ??
        <String, PersonPatchPreferencesNotification>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mail != null) 'mail': mail,
      if (push != null) 'push': push,
    };
  }

  @override
  String toString() {
    return 'PersonPatchPreferencesNotification[mail=$mail, push=$push, ]';
  }
}
